@@ -6,11 +6,12 @@ import wget
 import os
 import requests
 from datetime import datetime
-
+from zipfile import ZipFile
+from urllib.request import urlopen 
 
 def getData(State=None):
     dir_list = os.listdir()
-    state_ids = pd.read_csv('us-state-ansi-fips.csv',skipinitialspace=True, dtype=str)
+    state_ids = pd.read_csv(r'https://raw.githubusercontent.com/Fair-Lines-America/FLA_basic_tools/main/data/us-state-ansi-fips.csv'skipinitialspace=True, dtype=str)
     st = state_ids[state_ids['st']==State]
     st = st['stname'].iloc[0]
     if '2020_PLSummaryFile_FieldNames.xlsx' not in dir_list:
